Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrFieldNotExists = errors.New("field doesn't exist")
var ErrFieldWrongType = errors.New("field has a wrong type")
Functions ¶
This section is empty.
Types ¶
type Event ¶
type Event struct {
Connector string `json:"connector" example:"test_connector"`
ConnectorName string `json:"connector_name" example:"test_connectorname"`
SourceType string `json:"source_type" example:"resource"`
EventType string `json:"event_type" example:"check"`
Component string `json:"component,omitempty" example:"test_component"`
State string `json:"state,omitempty" example:"1"`
Resource string `json:"resource" example:"test_resource"`
}
Event structure used with swagger
type Response ¶
type Response struct {
SentEvents []Event `json:"sent_events"`
// FailedEvents is an empty array left for compatibility with old handler
FailedEvents []interface{} `json:"failed_events"`
// RetryEvents is an empty array left for compatibility with old handler
RetryEvents []interface{} `json:"retry_events"`
}
Response structure used with swagger
Click to show internal directories.
Click to hide internal directories.